translate.storage.properties.javautf8file

Package translate :: Package storage :: Module properties :: Class javautf8file |
[hide private]
[frames] | no frames]

# Class javautf8file

source code

Nested Classes | [hide private]
Inherited from `propfile`: `UnitClass`

Instance Methods | [hide private]
__init__(self, *args, **kwargs) construct a propfile, optionally reading in from inputfile | source code
Inherited from `propfile`: `__str__`, `parse` Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `detect_encoding`, `findid`, `findunit`, `findunits`, `getids`, `getprojectstyle`, `getsourcelanguage`, `gettargetlanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setprojectstyle`, `setsourcelanguage`, `settargetlanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
| Name = `_("Java Properties (UTF-8)")` The human usable name of this store type
| Exensions = `['properties']`
Inherited from `base.TranslationStore`: `Extensions`, `Mimetypes`, `sourcelanguage`, `suggestions_in_format`, `targetlanguage` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, *args, **kwargs) (Constructor) | source code
construct a propfile, optionally reading in from inputfile Overrides: object.__init__ (inherited documentation)